/// <reference types="react" />
import { IViewerCtor, IViewerProps, IViewerState } from '../../definition';
import { AnyT } from '../../definitions.interface';
import { GenericComponent } from '../base/generic.component';
export declare class Viewer<TProps extends IViewerProps = IViewerProps, TState extends IViewerState = IViewerState> extends GenericComponent<TProps, TState> {
    static readonly defaultProps: IViewerProps;
    private static readonly DEFAULT_PAGE;
    private readonly previewDialogRef;
    /**
     * @stable [13.12.2020]
     * @param originalProps
     */
    constructor(originalProps: TProps);
    /**
     * @stable [13.12.2020]
     * @param prevProps
     * @param prevState
     */
    componentDidUpdate(prevProps: TProps, prevState: TState): void;
    /**
     * @stable [16.03.2020]
     */
    componentDidMount(): void;
    /**
     * @stable [13.12.2020]
     */
    render(): JSX.Element;
    /**
     * @stable [14.12.2020]
     * @protected
     */
    protected get previewExtraActionsElement(): JSX.Element;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get previewForwardActionElement(): JSX.Element;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get previewBackActionElement(): JSX.Element;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get incrementScaleActionElement(): JSX.Element;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get decrementScaleActionElement(): JSX.Element;
    /**
     * @stable [18.03.2020]
     * @param {AnyT} error
     */
    protected onLoadError(error: AnyT): void;
    /**
     * @stable [18.03.2020]
     * @param {(...args) => void} callback
     */
    protected onLoadSucceed(callback?: (...args: any[]) => void): void;
    /**
     * @stable [18.03.2020]
     */
    protected onLoadStart(): void;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get isPreviewForwardActionDisabled(): boolean;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get isPreviewBackActionDisabled(): boolean;
    /**
     * @stable [14.12.2020]
     * @protected
     */
    protected get isDecrementScaleActionDisabled(): boolean;
    /**
     * @stable [14.12.2020]
     * @protected
     */
    protected getClassName(): string;
    /**
     * @stable [16.03.2020]
     */
    protected refreshOnSrcChanges(): void;
    /**
     * @stable [16.03.2020]
     */
    protected refreshOnInternalChanges(): void;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get contentElement(): JSX.Element;
    /**
     * @stable [13.12.2020]
     * @protected
     */
    protected get previewElement(): JSX.Element;
    /**
     * @stable [14.12.2020]
     */
    protected get inProgress(): boolean;
    /**
     * @stable [14.12.2020]
     * @private
     */
    private onPreviewDialogClose;
    /**
     * @stable [14.12.2020]
     * @private
     */
    private onPreviewDialogOpen;
    /**
     * @stable [13.12.2020]
     * @param prevProps
     * @param prevState
     * @private
     */
    private hasInternalChanges;
    /**
     * @stable [13.12.2020]
     * @param prevProps
     * @param prevState
     * @private
     */
    private hasScaleChanges;
    /**
     * @stable [13.12.2020]
     * @param prevProps
     * @param prevState
     * @private
     */
    private hasSrcChanges;
    /**
     * @stable [13.12.2020]
     * @param prevProps
     * @param prevState
     * @private
     */
    private hasInlineDialogBeenClosed;
    /**
     * @stable [13.12.2020]
     * @param prevProps
     * @param prevState
     * @private
     */
    private hasPageChanges;
    /**
     * @stable [16.03.2020]
     */
    private onBack;
    /**
     * @stable [16.03.2020]
     */
    private onForward;
    /**
     * @stable [16.03.2020]
     */
    private onIncrementScale;
    /**
     * @stable [14.12.2020]
     */
    private onDecrementScale;
    /**
     * @stable [16.03.2020]
     */
    private showPreviewDialog;
    /**
     * @stable [14.12.2020]
     * @private
     */
    private get nextDecrementPreviewScale();
    /**
     * @stable [16.03.2020]
     * @returns {number}
     */
    protected get actualOrDefaultPage(): number;
    /**
     * @stable [02.10.2020]
     */
    protected get actualPage(): number;
    /**
     * @stable [16.03.2020]
     * @returns {number}
     */
    protected get actualOrDefaultPreviewPage(): number;
    /**
     * @stable [16.03.2020]
     * @returns {number}
     */
    protected get actualPreviewPage(): number;
    /**
     * @stable [02.10.2020]
     */
    protected get actualOrDefaultPreviewScale(): number;
    /**
     * @stable [02.10.2020]
     */
    protected get actualOrDefaultScale(): number;
    /**
     * @stable [18.03.2020]
     * @returns {string}
     */
    protected get actualSrc(): string;
    /**
     * @stable [23.03.2020]
     * @returns {number}
     */
    protected get defaultScaleDiff(): number;
    /**
     * @stable [23.03.2020]
     * @returns {number}
     */
    protected get defaultScale(): number;
    /**
     * @stable [14.12.2020]
     * @protected
     */
    protected get ctor(): IViewerCtor;
    /**
     * @stable [14.12.2020]
     * @private
     */
    private get bodyElement();
    /**
     * @stable [14.12.2020]
     * @private
     */
    private get previewDialogElement();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isPreviewDialogOpened();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isBodyElementRendered();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isPreviewDialogInline();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get previewDialogConfiguration();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get previewIconElement();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isInfoRendered();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get canPreview();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get doesErrorExist();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isActualSrcAbsent();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isSrcAbsent();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isDefaultSrcAbsent();
    /**
     * @stable [13.12.2020]
     * @private
     */
    private get isPreviewUsed();
}
