import { IBirthdayWrapper, IDateWrapper, IDayWrapper, IDurationWrapper, IFromToEntity, IInputFormatWrapper, IInputTimeFormatWrapper, IIsoWeekWrapper, ILocaleWrapper, IMaxDateWrapper, IMinDateWrapper, IMonthWrapper, IOutputFormatWrapper, IOutputTimeFormatWrapper, IPeriodModeWrapper, IPeriodTypeWrapper, IReturnUndefWrapper, IStrictWrapper, ITimeWrapper, IUnitWrapper, IYearWrapper, IZoneWrapper, StringNumberT } from '../definitions.interface';
import { IIndexEntity } from './entity-definition.interface';
/**
 * @stable [22.12.2019]
 */
export declare type DateTimeLikeTypeT = string | Date;
/**
 * @stable [06.03.2020]
 */
export declare enum DatePeriodsEnum {
    CUSTOM = 0,
    DAY = 1,
    MONTH = 2,
    PREVIOUS_DAY = 3,
    PREVIOUS_MONTH = 4,
    PREVIOUS_QUARTER = 5,
    PREVIOUS_WEEK = 6,
    QUARTER = 7,
    WEEK = 8
}
/**
 * @stable [25.03.2020]
 */
export declare const DAYS_PERIODS: DatePeriodsEnum[];
export declare const WEEKS_PERIODS: DatePeriodsEnum[];
export declare const MONTHS_PERIODS: DatePeriodsEnum[];
export declare const QUARTERS_PERIODS: DatePeriodsEnum[];
/**
 * @config-entity
 * @stable [14.01.2021]
 */
export interface IWeekConfigEntity extends IIsoWeekWrapper, ILocaleWrapper {
}
/**
 * @config-entity
 * @stable [14.01.2021]
 */
export interface IDateTimeIndexConfigEntity extends IIndexEntity {
}
/**
 * @config-entity
 * @stable [17.12.2019]
 */
export interface IDateTimeConfigEntity<TDate> extends IDateTimeIndexConfigEntity, IDateWrapper<DateTimeLikeTypeT | TDate>, IDurationWrapper<StringNumberT>, IInputFormatWrapper, IInputTimeFormatWrapper, IIsoWeekWrapper, IOutputFormatWrapper, IOutputTimeFormatWrapper, IReturnUndefWrapper, IStrictWrapper, ITimeWrapper, IUnitWrapper<string>, IZoneWrapper {
}
/**
 * @stable [07.03.2020]
 */
export declare type DatesRangeValueT = (DateTimeLikeTypeT | DatePeriodsEnum)[];
/**
 * @entity
 * @stable [26.03.2020]
 */
export interface IDatePeriodModeEntity extends IPeriodModeWrapper<DatePeriodsEnum> {
}
/**
 * @entity
 * @stable [26.03.2020]
 */
export interface IDatePeriodTypeEntity extends IPeriodTypeWrapper<DatePeriodsEnum> {
}
/**
 * @entity
 * @stable [07.03.2020]
 */
export interface IDatesRangeEntity extends IFromToEntity<DateTimeLikeTypeT>, IDatePeriodModeEntity {
}
/**
 * @config-entity
 * @stable [21.01.2020]
 */
export interface IMinMaxDatesRangeConfigEntity extends IDateWrapper<Date>, IMaxDateWrapper<Date>, IMinDateWrapper<Date> {
}
/**
 * @config-entity
 * @stable [22.01.2020]
 */
export interface IPersonAgeConfigEntity<TDate = Date> extends IDateTimeConfigEntity<TDate>, IBirthdayWrapper {
}
/**
 * @entity
 * @stable [07.01.2020]
 */
export interface IDayOfYearEntity extends IDayWrapper, IFromToEntity<boolean>, IMonthWrapper, IYearWrapper {
}
/**
 * @entity
 * @stable [07.01.2020]
 */
export interface IFromToDayOfYearEntity extends IFromToEntity<IDayOfYearEntity> {
}
