"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StorageUtils = void 0;
var definition_1 = require("../definition");
var cond_1 = require("./cond");
var filter_1 = require("./filter");
var type_1 = require("./type");
var uuid_1 = require("./uuid");
/**
 * @stable [04.09.2020]
 * @param changes
 * @param fieldsValuesResolvers
 * @param storageProcessor
 */
var entitiesAsStorageTasks = function (changes, fieldsValuesResolvers, storageProcessor) {
    return Promise.all(fieldsValuesResolvers.map(function (fieldValueResolver) {
        var fieldValueChange = fieldValueResolver(changes);
        return cond_1.ConditionUtils.orNull(type_1.TypeUtils.isDef(fieldValueChange), function () { return storageProcessor(uuid_1.UuidUtils.uuid(), fieldValueChange); });
    }));
};
/**
 * @stable [24.12.2020]
 * @param result
 */
var asSingleAddedFileId = function (result) { var _a; return (_a = result === null || result === void 0 ? void 0 : result.addedFiles[0]) === null || _a === void 0 ? void 0 : _a.id; };
/**
 * @stable [10.09.2020]
 * @param env
 */
var asNotVersionedKey = function (env) {
    return filter_1.FilterUtils
        .notEmptyObjectValuesArrayFilter(env.appProfile, env.port, env.normalizedBasePath)
        .join(definition_1.DefaultEntities.PATH_SEPARATOR);
};
/**
 * @stable [10.09.2020]
 * @param env
 */
var asVersionedKey = function (env) {
    return filter_1.FilterUtils
        .notEmptyObjectValuesArrayFilter(env.appVersion, asNotVersionedKey(env))
        .join(definition_1.DefaultEntities.PATH_SEPARATOR);
};
/**
 * @stable [04.09.2020]
 */
var StorageUtils = /** @class */ (function () {
    function StorageUtils() {
    }
    StorageUtils.asNotVersionedKey = asNotVersionedKey;
    StorageUtils.asSingleAddedFileId = asSingleAddedFileId;
    StorageUtils.asVersionedKey = asVersionedKey;
    StorageUtils.entitiesAsStorageTasks = entitiesAsStorageTasks;
    return StorageUtils;
}());
exports.StorageUtils = StorageUtils;
//# sourceMappingURL=storage.js.map